==> ogre-next-2.2.4-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/_ogre_compositor_pass_def_8h.js <==
var _ogre_compositor_pass_def_8h =
[
    [ "UavDependency", "struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency.html", "struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency" ],
    [ "ViewportRect", "struct_ogre_1_1_compositor_pass_def_1_1_viewport_rect.html", "struct_ogre_1_1_compositor_pass_def_1_1_viewport_rect" ],
    [ "CompositorPassDefVec", "_ogre_compositor_pass_def_8h.html#ga5cc23a9ff066c8ba7a6c1275453ea590", null ],
    [ "CompositorPassType", "_ogre_compositor_pass_def_8h.html#ga6f176e5de375550ba7f1c8dccde8345a", [
      [ "PASS_INVALID", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa3237339678fe18c0dfdda0de205da6ae", null ],
      [ "PASS_SCENE", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aab48a9dc44373ebd060553b5414cf3763", null ],
      [ "PASS_QUAD", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa827c9da8b4d2c6396c465e7770a37432", null ],
      [ "PASS_CLEAR", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa9c46aff8b9f028c74fbf6d3cf0836a9f", null ],
      [ "PASS_STENCIL", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa7715d41e8d049b2b8aca7e7f6813fbf4", null ],
      [ "PASS_RESOLVE", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa22534e9baf168dbbb1c9b81d5721794e", null ],
      [ "PASS_DEPTHCOPY", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aaece5ac965f939ab909ec7082fdea92d8", null ],
      [ "PASS_UAV", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa64169071182113bc2f2612ce360d83dc", null ],
      [ "PASS_MIPMAP", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa43539099735fda358fe3b01e3536933f", null ],
      [ "PASS_IBL_SPECULAR", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa0fe924f8a19ffe8a3d7c0445946d7ec5", null ],
      [ "PASS_COMPUTE", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa973bc7a5a948dd54130595d7539eb7ba", null ],
      [ "PASS_CUSTOM", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa8be4347345faa339a4c663a8c5da1c51", null ]
    ] ],
    [ "CompositorPassTypeEnumNames", "_ogre_compositor_pass_def_8h.html#ga88c007cd7c351ae388b1a7dba5b652fe", null ]
];

==> ogre-next-2.3.0-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/_ogre_compositor_pass_def_8h.js <==
var _ogre_compositor_pass_def_8h =
[
    [ "Ogre::CompositorPassDef::UavDependency", "struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency.html", "struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency" ],
    [ "Ogre::CompositorPassDef::ViewportRect", "struct_ogre_1_1_compositor_pass_def_1_1_viewport_rect.html", "struct_ogre_1_1_compositor_pass_def_1_1_viewport_rect" ],
    [ "CompositorPassDefVec", "_ogre_compositor_pass_def_8h.html#ga5cc23a9ff066c8ba7a6c1275453ea590", null ],
    [ "CompositorPassType", "_ogre_compositor_pass_def_8h.html#ga6f176e5de375550ba7f1c8dccde8345a", [
      [ "PASS_INVALID", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa3237339678fe18c0dfdda0de205da6ae", null ],
      [ "PASS_SCENE", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aab48a9dc44373ebd060553b5414cf3763", null ],
      [ "PASS_QUAD", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa827c9da8b4d2c6396c465e7770a37432", null ],
      [ "PASS_CLEAR", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa9c46aff8b9f028c74fbf6d3cf0836a9f", null ],
      [ "PASS_STENCIL", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa7715d41e8d049b2b8aca7e7f6813fbf4", null ],
      [ "PASS_RESOLVE", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa22534e9baf168dbbb1c9b81d5721794e", null ],
      [ "PASS_DEPTHCOPY", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aaece5ac965f939ab909ec7082fdea92d8", null ],
      [ "PASS_UAV", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa64169071182113bc2f2612ce360d83dc", null ],
      [ "PASS_MIPMAP", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa43539099735fda358fe3b01e3536933f", null ],
      [ "PASS_IBL_SPECULAR", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa0fe924f8a19ffe8a3d7c0445946d7ec5", null ],
      [ "PASS_SHADOWS", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa3ec0d9a6e1feeb393d5c3070589c9b60", null ],
      [ "PASS_TARGET_BARRIER", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa6b22361c61fe5c233b17230c5d795bfd", null ],
      [ "PASS_COMPUTE", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa973bc7a5a948dd54130595d7539eb7ba", null ],
      [ "PASS_CUSTOM", "_ogre_compositor_pass_def_8h.html#gga6f176e5de375550ba7f1c8dccde8345aa8be4347345faa339a4c663a8c5da1c51", null ]
    ] ],
    [ "CompositorPassTypeEnumNames", "_ogre_compositor_pass_def_8h.html#ga88c007cd7c351ae388b1a7dba5b652fe", null ]
];
